@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -49,18 +49,22 @@ from sys import modules as _modules
 # "beartype.meta" is the *ONLY* "beartype" submodule guaranteed to be safely
 # importable at install time. All other "beartype" submodules should be assumed
 # to be unsafe due to potentially importing one or more optional runtime
-# dependencies yet to be installed (e.g., "typing_extensions" package). See
-# "setup.py" for further details.
+# dependencies yet to be installed (e.g., "typing_extensions"). See "setup.py"
+# for gruesome details you did not want to know about.
 if 'beartype.__is_installing__' not in _modules:
     # Publicize the private @beartype._decor.beartype decorator as
     # @beartype.beartype, preserving all implementation details as private.
-    from beartype._decor.decormain import beartype
+    from beartype._decor.decormain import (
+        beartype as beartype,
+    )
 
     # Publicize all top-level configuration attributes required to configure the
     # @beartype.beartype decorator.
-    from beartype._conf import (
-        BeartypeConf,
-        BeartypeStrategy,
+    from beartype._conf.confcls import (
+        BeartypeConf as BeartypeConf,
+    )
+    from beartype._conf.confenum import (
+        BeartypeStrategy as BeartypeStrategy,
     )
 # Else, this submodule is *NOT* being imported at install time.
 
@@ -89,13 +93,13 @@ For PEP 8 compliance, this specifier has the canonical name
 '''
 
 
-# __all__ = [
-#     'BeartypeConf',
-#     'BeartypeStrategy',
-#     'beartype',
-#     '__version__',
-#     '__version_info__',
-# ]
+__all__ = [
+    'BeartypeConf',
+    'BeartypeStrategy',
+    'beartype',
+    '__version__',
+    '__version_info__',
+]
 '''
 Special list global of the unqualified names of all public package attributes
 explicitly exported by and thus safely importable from this package.
@@ -144,12 +148,12 @@ def __getattr__(attr_deprecated_name: str) -> object:
 
     Warns
     ----------
-    :class:`DeprecationWarning`
+    DeprecationWarning
         If this attribute is deprecated.
 
     Raises
     ----------
-    :exc:`AttributeError`
+    AttributeError
         If this attribute is unrecognized and thus erroneous.
     '''
 
@@ -170,6 +174,23 @@ def __getattr__(attr_deprecated_name: str) -> object:
         from beartype import door
         attr_nondeprecated_name_to_value = {'door': door}
         attr_nondeprecated_name_to_value.update(globals())
+    #FIXME: To support attribute-based deferred importation ala "lazy loading"
+    #of heavyweight subpackages like "beartype.door" and "beartype.vale", it
+    #looks like we'll need to manually add support here for that: e.g.,
+    #    elif attr_deprecated_name in {'cave', 'claw', 'door', 'vale',}:
+    #        #FIXME: Dynamically import this attribute here... somehow. Certainly, if
+    #        #such functionality does *NOT* exist, add it to the existing
+    #        #"utilmodimport" submodule: e.g.,
+    #        attr_value = import_module_attr(f'beartype.{attr_deprecated_name}')
+    #        attr_nondeprecated_name_to_value = {attr_deprecated_name: attr_value}
+    #FIXME: Rename "attr_deprecated_name" to merely "attr_name", please.
+    #FIXME: Revise docstring accordingly, please.
+    #FIXME: Exhaustively test this, please. Because we'll never manage to keep
+    #this in sync, we *ABSOLUTELY* should author a unit test that:
+    #* Decides the set of all public subpackages of "beartype".
+    #* Validates that each subpackage in this set is accessible as a
+    #  "beartype.{subpackage_name}" attribute.
+
     # Else, this deprecated attribute is any other attribute.
 
     # Return the value of this deprecated attribute and emit a warning.
