@@ -27,6 +27,7 @@ from beartype.roar import (
 )
 from beartype.typing import no_type_check
 from beartype._cave._cavefast import (
+    MethodBoundInstanceOrClassType,
     MethodDecoratorBuiltinTypes,
     MethodDecoratorClassType,
     MethodDecoratorPropertyType,
@@ -40,7 +41,7 @@ from beartype._data.datatyping import (
     TypeWarning,
 )
 from beartype._data.cls.datacls import TYPES_BEARTYPEABLE
-from beartype._decor._wrapper.wrappermain import generate_code
+from beartype._decor._wrap.wrapmain import generate_code
 from beartype._check.checkcall import BeartypeCall
 from beartype._util.cache.pool.utilcachepoolobjecttyped import (
     acquire_object_typed,
@@ -51,6 +52,7 @@ from beartype._util.func.lib.utilbeartypefunc import (
     set_func_beartyped,
 )
 from beartype._util.func.utilfuncmake import make_func
+from beartype._util.func.utilfunctest import is_func_python
 from beartype._util.mod.utilmodget import get_object_module_line_number_begin
 from beartype._util.utilobject import get_object_name
 from traceback import format_exc
@@ -142,7 +144,7 @@ def beartype_object(
         Nonetheless, this tuple intentionally preserves *all* of those other
         nested classes. Why? Because :pep:`563` resolution can only find the
         parent callable lexically containing that nested class hierarchy on the
-        current call stack (if any) treating the total number of classes
+        current call stack (if any) by leveraging the total number of classes
         lexically nesting the currently decorated class as input metadata, as
         trivially provided by the length of this tuple.
 
@@ -161,6 +163,7 @@ def beartype_object(
     :func:`beartype._decor.decormain.beartype`
         Memoized parent decorator wrapping this unmemoized child decorator.
     '''
+    # print(f'Decorating object {repr(obj)}...')
 
     # If this object is a class, return this class decorated with type-checking.
     #
@@ -181,12 +184,14 @@ def beartype_object(
     #
     # In all cases, "cls_curr" conveys *NO* meaningful semantics.
     if isinstance(obj, type):
+        # print(f'Decorating type {repr(obj)}...')
         return _beartype_type(  # type: ignore[return-value]
             cls=obj,
             conf=conf,
             cls_stack=cls_stack,
         )
     # Else, this object is a non-class.
+    # print(f'Decorating non-type {repr(obj)}...')
 
     # Type of this object.
     obj_type = type(obj)
@@ -221,7 +226,7 @@ def beartype_object(
     #   * Descriptors created by @staticmethod are technically callable but
     #     C-based and thus unsuitable for decoration.
     if obj_type in MethodDecoratorBuiltinTypes:
-        return _beartype_descriptor(  # type: ignore[return-value]
+        return _beartype_decorator_builtin(  # type: ignore[return-value]
             descriptor=obj,
             conf=conf,
             cls_stack=cls_stack,
@@ -234,6 +239,18 @@ def beartype_object(
         raise BeartypeDecorWrappeeException(
             f'Uncallable {repr(obj)} not decoratable by @beartype.')
     # Else, this object is callable.
+    #
+    # If this object is *NOT* a pure-Python function, attempt to monkey-patch
+    # runtime type-checking into this object by replacing all bound method
+    # descriptors of this object with comparable descriptors calling
+    # @beartype-generated runtime type-checking wrapper functions.
+    elif not is_func_python(obj):
+        return _monkeypatch_object(  # type: ignore[return-value]
+            obj=obj,
+            conf=conf,
+            cls_stack=cls_stack,
+        )
+    # Else, this object is a pure-Python function.
 
     # Return a new callable decorating that callable with type-checking.
     return _beartype_func(  # type: ignore[return-value]
@@ -376,7 +393,7 @@ def beartype_object_nonfatal(
     return obj
 
 # ....................{ PRIVATE ~ beartypers : func        }....................
-def _beartype_descriptor(
+def _beartype_decorator_builtin(
     # Mandatory parameters.
     descriptor: BeartypeableT,
     conf: BeartypeConf,
@@ -385,7 +402,9 @@ def _beartype_descriptor(
     **kwargs
 ) -> BeartypeableT:
     '''
-    Decorate the passed C-based unbound method descriptor with dynamically
+    Decorate the passed **builtin decorator object** (i.e., C-based unbound
+    method descriptor produced by the builtin :class:`classmethod`,
+    :class:`property`, or :class:`staticmethod` decorators) with dynamically
     generated type-checking.
 
     Parameters
@@ -396,16 +415,23 @@ def _beartype_descriptor(
         Beartype configuration configuring :func:`beartype.beartype` uniquely
         specific to this descriptor.
 
-    All remaining keyword parameters are passed as is to the
-    :func:`_beartype_func` decorator.
+    All remaining keyword parameters are passed as is to the lower-level
+    :func:`_beartype_func` decorator internally called by this higher-level
+    decorator on the pure-Python function encapsulated in this descriptor.
 
     Returns
     ----------
     BeartypeableT
         New pure-Python callable wrapping this descriptor with type-checking.
+
+    Raises
+    ----------
+    BeartypeDecorWrappeeException
+        If this descriptor is neither a class, property, or static method
+        descriptor.
     '''
-    assert isinstance(descriptor, MethodDecoratorBuiltinTypes), (
-        f'{repr(descriptor)} not builtin method descriptor.')
+    # assert isinstance(descriptor, MethodDecoratorBuiltinTypes), (
+    #     f'{repr(descriptor)} not builtin method descriptor.')
     # assert isinstance(conf, BeartypeConf), f'{repr(conf)} not configuration.'
 
     # Type of this descriptor.
@@ -493,32 +519,6 @@ def _beartype_descriptor(
         return staticmethod(func_checked)  # type: ignore[return-value]
     # Else, this descriptor is *NOT* a static method.
 
-    #FIXME: Unconvinced this edge case is required or desired. Does @beartype
-    #actually need to decorate instance method descriptors? Nonetheless, this
-    #is sufficiently useful to warrant preservation... probably.
-    #FIXME: Unit test us up, please.
-    # # If this descriptor is an instance method...
-    # #
-    # # Note that instance method descriptors are intentionally tested first, as
-    # # most methods are instance methods.
-    # if descriptor_type is MethodBoundInstanceOrClassType:
-    #     # Pure-Python unbound function decorating the similarly pure-Python
-    #     # unbound function wrapped by this descriptor with type-checking.
-    #     descriptor_func = _beartype_func(func=descriptor.__func__, conf=conf)
-    #
-    #     # New instance method descriptor rebinding this function to the
-    #     # instance of the class bound to the prior descriptor.
-    #     descriptor_new = MethodBoundInstanceOrClassType(
-    #         descriptor_func, descriptor.__self__)  # type: ignore[return-value]
-    #
-    #     # Propagate the docstring from the prior to new descriptor.
-    #     descriptor_new.__doc__ = descriptor.__doc__
-    #
-    #     # Return this new descriptor, implicitly destroying the prior
-    #     # descriptor.
-    #     return descriptor_new
-    # Else, this descriptor is *NOT* an instance method.
-
     # Raise a fallback exception. This should *NEVER happen. This *WILL* happen.
     raise BeartypeDecorWrappeeException(
         f'Builtin method descriptor {repr(descriptor)} '
@@ -527,6 +527,93 @@ def _beartype_descriptor(
     )
 
 
+def _beartype_method_bound(
+    # Mandatory parameters.
+    descriptor: BeartypeableT,
+    conf: BeartypeConf,
+
+    # Variadic keyword parameters.
+    **kwargs
+) -> BeartypeableT:
+    '''
+    Decorate the passed **builtin bound method object** (i.e., C-based bound
+    method descriptor produced by Python on instantiation for each instance and
+    class method defined by the class being instantiated) with dynamically
+    generated type-checking.
+
+    Parameters
+    ----------
+    descriptor : BeartypeableT
+        Descriptor to be decorated by :func:`beartype.beartype`.
+    conf : BeartypeConf
+        Beartype configuration configuring :func:`beartype.beartype` uniquely
+        specific to this descriptor.
+
+    All remaining keyword parameters are passed as is to the lower-level
+    :func:`_beartype_func` decorator internally called by this higher-level
+    decorator on the pure-Python function encapsulated in this descriptor.
+
+    Returns
+    ----------
+    BeartypeableT
+        New pure-Python callable wrapping this descriptor with type-checking.
+    '''
+    assert isinstance(descriptor, MethodBoundInstanceOrClassType), (
+        f'{repr(descriptor)} not builtin bound method descriptor.')
+
+    # Pure-Python unbound function encapsulated by this descriptor.
+    descriptor_func_old = descriptor.__func__
+
+    # Pure-Python unbound function decorating the similarly pure-Python unbound
+    # function encapsulated by this descriptor with type-checking.
+    #
+    # Note that doing so:
+    # * Implicitly propagates dunder attributes (e.g., "__annotations__",
+    #   "__doc__") from the original function onto this new function. Good.
+    # * Does *NOT* implicitly propagate the same dunder attributes from the
+    #   original descriptor encapsulating the original function to the new
+    #   descriptor (created below) encapsulating this wrapper function. Bad!
+    #   Thankfully, only one such attribute exists as of this time: "__doc__".
+    #   We propagate this attribute manually below.
+    descriptor_func_new = _beartype_func(func=descriptor_func_old, conf=conf)  # pyright: ignore[reportGeneralTypeIssues]
+
+    # New instance method descriptor rebinding this function to the instance of
+    # the class bound to the prior descriptor.
+    #
+    # Note that:
+    # * This is required, as the "__func__" attribute of method descriptors is
+    #   read-only. Attempting to do so raises this non-human-readable exception:
+    #     AttributeError: readonly attribute
+    #   This implies that the passed descriptor *CANNOT* be meaningfully
+    #   modified. Our only recourse is to define an entirely new descriptor,
+    #   effectively discarding the passed descriptor, which will then be
+    #   subsequently garbage-collected. This is wasteful. This is Python.
+    # * This can also be implemented by abusing the descriptor protocol:
+    #       descriptor_new = descriptor_func_new.__get__(descriptor.__self__)
+    #   That said, there exist *NO* benefits to doing so. Indeed, doing so only
+    #   reduces the legibility and maintainability of this operation.
+    descriptor_new = MethodBoundInstanceOrClassType(
+        descriptor_func_new, descriptor.__self__)  # type: ignore[return-value]
+
+    #FIXME: Actually, Python doesn't appear to support this at the moment.
+    #Attempting to do so raises this exception:
+    #    AttributeError: attribute '__doc__' of 'method' objects is not writable
+    #
+    #See also this open issue on the Python bug tracker requesting this be
+    #resolved. Sadly, Python has yet to resolve this:
+    #    https://bugs.python.org/issue47153
+    # # Propagate the docstring from the prior to the new descriptor.
+    # #
+    # # Note that Python guarantees this attribute to exist. If the original
+    # # function had a docstring, this attribute is non-"None"; else, this
+    # # attribute is "None". In either case, this attribute exists. Ergo,
+    # # additional validation is neither required nor desired.
+    # descriptor_new.__doc__ = descriptor.__doc__
+
+    # Return this new descriptor, implicitly destroying the prior descriptor.
+    return descriptor_new  # type: ignore[return-value]
+
+
 def _beartype_func(
     # Mandatory parameters.
     func: BeartypeableT,
@@ -657,11 +744,8 @@ def _beartype_type(
         specific to this class.
     cls_stack : TypeStack
         **Type stack** (i.e., either tuple of zero or more arbitrary types *or*
-        ``None``). Defaults to ``None``. See also :func:`beartype_object`.
-
-    Note this function intentionally accepts *no* ``cls_curr`` parameter, unlike
-    most functions defined by this submodule. See :func:`beartype_object` for
-    further details.
+        ``None``). Defaults to ``None``. See also the :func:`beartype_object`
+        decorator for further commentary.
 
     Returns
     ----------
@@ -753,3 +837,99 @@ def _beartype_type(
 
     # Return this class as is.
     return cls  # type: ignore[return-value]
+
+# ....................{ PRIVATE ~ patchers                 }....................
+#FIXME: Generalize to iteratively monkey-patch *ALL* bound method descriptors of
+#this object. Currently, this method only monkey-patches the __call__() method.
+#Note that doing so will prove slightly non-trivial, as we'll need to handle
+#both:
+#* Special dunder methods like __call__() and __getitem__(), which Python
+#  ignores unless defined on the *CLASS* of this object rather than this object
+#  itself.
+#* All other methods, which should be defined on this object itself for safety.
+def _monkeypatch_object(
+    # Mandatory parameters.
+    obj: BeartypeableT,
+    conf: BeartypeConf,
+
+    # Variadic keyword parameters.
+    **kwargs
+) -> BeartypeableT:
+    '''
+    Monkey-patch the passed **arbitrary object** (i.e., pure-Python object
+    assumed *not* to be handled by other higher-level decorators defined by this
+    submodule and thus neither a class, function, nor builtin decorator
+    descriptor) with dynamically generated type-checking.
+
+    For each bound method descriptor encapsulating a method bound to this
+    object, this function monkey-patches (i.e., replaces) that descriptor with a
+    comparable descriptor calling a new :func:`beartype.beartype`-generated
+    runtime type-checking wrapper function wrapping the original method.
+
+    Parameters
+    ----------
+    obj : BeartypeableT
+        Object to be monkey-patched by :func:`beartype.beartype`.
+    conf : BeartypeConf
+        Beartype configuration configuring :func:`beartype.beartype` uniquely
+        specific to this descriptor.
+
+    All remaining keyword parameters are passed as is to the lower-level
+    :func:`_beartype_func` decorator internally called by this higher-level
+    decorator on the pure-Python function encapsulated in this descriptor.
+
+    Returns
+    ----------
+    BeartypeableT
+        The object monkey-patched by :func:`beartype.beartype`.
+    '''
+    # print(f'@beartyping pseudo-callable {repr(obj)}...')
+
+    # __call__() dunder method defined by this object if this object defines
+    # this method *OR* "None" otherwise.
+    obj_call_method = getattr(obj, '__call__')
+
+    # If this object does *NOT* define this method, this object is *NOT* a
+    # pseudo-callable. In this case, raise an exception.
+    #
+    # Note this edge case should *NEVER* occur. By definition, this object has
+    # already been validated to be callable. But this object is *NOT* a
+    # pure-Python function. Since the only other category of callable in Python
+    # is a pseudo-callable, this object *MUST* be a pseudo-callable. That said,
+    # languages change; it's not inconceivable that Python could introduce yet
+    # another kind of callable object under future versions.
+    if obj_call_method is None:
+        raise BeartypeDecorWrappeeException(  # pragma: no cover
+            f'Callable {repr(obj)} not pseudo-callable (i.e., callable '
+            f'object defining __call__() dunder method).'
+        )
+    # Else, this object is a pseudo-callable.
+
+    # Replace the existing bound method descriptor to this __call__() dunder
+    # method  with a new bound method descriptor to a new __call__() dunder
+    # method wrapping the old method with runtime type-checking.
+    #
+    # Note that:
+    # * This is a monkey-patch. Since the caller is intentionally decorating
+    #   this pseudo-callable with @beartype, this is exactly what the caller
+    #   wanted. Probably.
+    # * This monkey-patches the *CLASS* of this object rather than this object
+    #   itself. Why? Because Python. For unknown reasons (so, speed is what
+    #   we're saying), Python accesses dunder methods on the *CLASS* of an
+    #   object rather than on the object itself. Of course, this implies that
+    #   *ALL* instances of this pseudo-callable (rather than
+    #   merely the passed instance) will be monkey-patched. This may *NOT*
+    #   necessarily be what the caller wanted. Unfortunately, the only
+    #   alternative would be for @beartype to raise an exception when passed a
+    #   pseudo-callable. Since doing something beneficial is generally
+    #   preferable to doing something harmful, @beartype prefers the former. See
+    #   also official documentation on the subject:
+    #       https://docs.python.org/3/reference/datamodel.html#special-method-names
+    obj.__class__.__call__ = _beartype_method_bound(  # type: ignore[assignment,method-assign]
+        descriptor=obj_call_method,
+        conf=conf,
+        **kwargs,
+    )
+
+    # Return this monkey-patched object.
+    return obj  # type: ignore[return-value]
