@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -33,14 +33,16 @@ from beartype.door._doortyping import (
     BeartypeTypeChecker,
 )
 from beartype.roar import (
-    BeartypeAbbyHintViolation,
-    BeartypeAbbyTesterException,
     BeartypeCallHintReturnViolation,
+    BeartypeDoorHintViolation,
 )
 from beartype.roar._roarexc import _BeartypeDoorTextException
 from beartype.typing import TYPE_CHECKING
 from beartype._check.checkmake import make_func_tester
-from beartype._conf import BeartypeConf
+from beartype._conf.confcls import (
+    BEARTYPE_CONF_DEFAULT,
+    BeartypeConf,
+)
 from beartype._decor._cache.cachedecor import beartype
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.error.utilerror import reraise_exception_placeholder
@@ -50,7 +52,7 @@ from beartype._util.mod.lib.utiltyping import import_typing_attr_or_fallback
 
 # ....................{ HINTS                              }....................
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-# CAUTION: Synchronize with similar logic in "beartype.door._doorcls".
+# CAUTION: Synchronize with similar logic in "beartype.door._cls.doorsuper".
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 #FIXME: This approach is *PHENOMENAL.* No. Seriously, We could implement a
@@ -97,7 +99,7 @@ def die_if_unbearable(
 
     # Optional keyword-only parameters.
     *,
-    conf: BeartypeConf = BeartypeConf(),
+    conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
 ) -> None:
     '''
     Raise an exception if the passed arbitrary object violates the passed
@@ -116,20 +118,20 @@ def die_if_unbearable(
 
     Raises
     ----------
-    BeartypeAbbyHintViolation
-        If this object violates this hint.
-    BeartypeDecorHintNonpepException
+    beartype.roar.BeartypeDecorHintNonpepException
         If this hint is *not* PEP-compliant (i.e., complies with *no* Python
         Enhancement Proposals (PEPs) currently supported by :mod:`beartype`).
-    BeartypeDecorHintPepUnsupportedException
+    beartype.roar.BeartypeDecorHintPepUnsupportedException
         If this hint is currently unsupported by :mod:`beartype`.
+    beartype.roar.BeartypeDoorHintViolation
+        If this object violates this hint.
 
     Examples
     ----------
         >>> from beartype.door import die_if_unbearable
         >>> die_if_unbearable(['And', 'what', 'rough', 'beast,'], list[str])
         >>> die_if_unbearable(['its', 'hour', 'come', 'round'], list[int])
-        beartype.roar.BeartypeAbbyHintViolation: Object ['its', 'hour', 'come',
+        beartype.roar.BeartypeDoorHintViolation: Object ['its', 'hour', 'come',
         'round'] violates type hint list[int], as list index 0 item 'its' not
         instance of int.
     '''
@@ -158,7 +160,7 @@ def die_if_unbearable(
         if not exception_message.startswith(
             _TYPE_CHECKER_EXCEPTION_MESSAGE_PREFIX):
             raise _BeartypeDoorTextException(
-                f'_get_type_checker._die_if_unbearable() exception '
+                f'_check_object() exception '
                 f'"{exception_message}" not prefixed by '
                 f'"{_TYPE_CHECKER_EXCEPTION_MESSAGE_PREFIX}".'
             ) from exception
@@ -172,7 +174,10 @@ def die_if_unbearable(
         )
 
         # Wrap this exception in a more readable higher-level exception.
-        raise BeartypeAbbyHintViolation(exception_message) from exception
+        raise BeartypeDoorHintViolation(
+            message=exception_message,
+            culprits=exception.culprits,
+        ) from exception
     # Else, this closure raised another exception. In this case, percolate this
     # exception back up this call stack.
 
@@ -237,12 +242,12 @@ def is_subhint(subhint: object, superhint: object) -> bool:
     '''
 
     # Avoid circular import dependencies.
-    from beartype.door._doorcls import TypeHint
+    from beartype.door._cls.doorsuper import TypeHint
 
     # The one-liner is mightier than the... many-liner.
     return TypeHint(subhint).is_subhint(TypeHint(superhint))
 
-# ....................{ TESTERS ~ is_bearable()            }....................
+# ....................{ TESTERS ~ is_bearable              }....................
 #FIXME: Improve unit tests to exhaustively exercise edge cases, including:
 #* Invalid hints. In this case, test that the raised exception is prefixed by
 #  the expected substring rather than our exception placeholder.
@@ -253,7 +258,8 @@ def is_bearable(
     hint: T,
 
     # Optional keyword-only parameters.
-    *, conf: BeartypeConf = BeartypeConf(),
+    *,
+    conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
 ) -> TypeGuard[T]:
     '''
     ``True`` only if the passed arbitrary object satisfies the passed
@@ -277,16 +283,16 @@ def is_bearable(
 
     Raises
     ----------
-    BeartypeConfException
+    beartype.roar.BeartypeConfException
         If this configuration is *not* a :class:`BeartypeConf` instance.
-    BeartypeDecorHintForwardRefException
+    beartype.roar.BeartypeDecorHintForwardRefException
         If this hint contains one or more relative forward references, which
         this tester explicitly prohibits to improve both the efficiency and
         portability of calls to this tester.
-    BeartypeDecorHintNonpepException
+    beartype.roar.BeartypeDecorHintNonpepException
         If this hint is *not* PEP-compliant (i.e., complies with *no* Python
         Enhancement Proposals (PEPs) currently supported by :mod:`beartype`).
-    BeartypeDecorHintPepUnsupportedException
+    beartype.roar.BeartypeDecorHintPepUnsupportedException
         If this hint is currently unsupported by :mod:`beartype`.
 
     Examples
@@ -308,8 +314,7 @@ def is_bearable(
     # by keyword would raise a non-fatal
     # "_BeartypeUtilCallableCachedKwargsWarning" warning.
     try:
-        func_tester = make_func_tester(
-            hint, conf, BeartypeAbbyTesterException)
+        func_tester = make_func_tester(hint, conf)
     # If any exception was raised, reraise this exception with each
     # placeholder substring (i.e., "EXCEPTION_PLACEHOLDER" instance)
     # replaced by the passed exception prefix.
@@ -372,8 +377,7 @@ def _get_type_checker(
     conf : BeartypeConf, optional
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all flags, options, settings, and other metadata configuring how this
-        object is type-checked). Defaults to ``BeartypeConf()``, the default
-        beartype configuration.
+        object is type-checked).
 
     Returns
     ----------
@@ -382,10 +386,10 @@ def _get_type_checker(
 
     Raises
     ----------
-    BeartypeDecorHintPepUnsupportedException
+    beartype.roar.BeartypeDecorHintPepUnsupportedException
         If this hint is a PEP-compliant type hint currently unsupported by
         the :func:`beartype.beartype` decorator.
-    BeartypeDecorHintNonpepException
+    beartype.roar.BeartypeDecorHintNonpepException
         If this hint is neither a:
 
         * Supported PEP-compliant type hint.
