@@ -101,7 +101,7 @@ justification of this constant's current value.
 '''
 
 
-PYTHON_VERSION_MINOR_MAX = 11
+PYTHON_VERSION_MINOR_MAX = 12
 '''
 Maximum minor stable version of this major version of Python currently released
 (e.g., ``5`` if Python 3.5 is the most recent stable version of Python 3.x).
@@ -139,7 +139,6 @@ tuple of integers.
 # Python version.
 #
 # The "sys" module exposes three version-related constants for this purpose:
-#
 # * "hexversion", an integer intended to be specified in an obscure (albeit
 #   both efficient and dependable) hexadecimal format: e.g.,
 #    >>> sys.hexversion
@@ -209,7 +208,7 @@ if _PYTHON_VERSION_PARTS < PYTHON_VERSION_MIN_PARTS:
 # For further details, see http://semver.org.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-VERSION = '0.12.0'
+VERSION = '0.13.0'
 '''
 Human-readable package version as a ``.``-delimited string.
 '''
@@ -243,7 +242,10 @@ comma-delimited string.
 
 For brevity, this string *only* lists authors explicitly assigned copyrights.
 For the list of all contributors regardless of copyright assignment or
-attribution, see the top-level ``AUTHORS.md`` file.
+attribution, see the `contributors graph`_ for this project.
+
+.. _contributors graph::
+   https://github.com/beartype/beartype/graphs/contributors
 '''
 
 
@@ -254,17 +256,33 @@ Legally binding copyright line excluding the license-specific prefix (e.g.,
 
 For brevity, this string *only* lists authors explicitly assigned copyrights.
 For the list of all contributors regardless of copyright assignment or
-attribution, see the top-level ``AUTHORS.md`` file.
+attribution, see the `contributors graph`_ for this project.
+
+.. _contributors graph::
+   https://github.com/beartype/beartype/graphs/contributors
 '''
 
-# ....................{ METADATA ~ urls                    }....................
-URL_HOMEPAGE = 'https://github.com/beartype/beartype'
+# ....................{ METADATA ~ urls : docs             }....................
+URL_HOMEPAGE = 'https://beartype.readthedocs.io'
 '''
 URL of this package's homepage.
 '''
 
 
-URL_DOWNLOAD = f'{URL_HOMEPAGE}/archive/{VERSION}.tar.gz'
+URL_PEP585_DEPRECATIONS = (
+    f'{URL_HOMEPAGE}/en/latest/api_roar/#pep-585-deprecations')
+'''
+URL documenting :pep:`585` deprecations of :pep:`484` type hints.
+'''
+
+# ....................{ METADATA ~ urls : repo             }....................
+URL_REPO = 'https://github.com/beartype/beartype'
+'''
+URL of this package's git repository.
+'''
+
+
+URL_DOWNLOAD = f'{URL_REPO}/archive/{VERSION}.tar.gz'
 '''
 URL of the source tarball for the current version of this package.
 
@@ -276,19 +294,19 @@ have yet to be stabilized and hence tagged. Hence, this URL is typically valid
 '''
 
 
-URL_FORUMS = f'{URL_HOMEPAGE}/discussions'
+URL_FORUMS = f'{URL_REPO}/discussions'
 '''
 URL of this package's user forums.
 '''
 
 
-URL_ISSUES = f'{URL_HOMEPAGE}/issues'
+URL_ISSUES = f'{URL_REPO}/issues'
 '''
 URL of this package's issue tracker.
 '''
 
 
-URL_RELEASES = f'{URL_HOMEPAGE}/releases'
+URL_RELEASES = f'{URL_REPO}/releases'
 '''
 URL of this package's release list.
 '''
@@ -394,10 +412,29 @@ LIBS_TESTTIME_OPTIONAL = (
     #
     # See also this upstream NumPy issue:
     #     https://github.com/numpy/numpy/issues/15947
-    'numpy; sys_platform != "darwin" and platform_python_implementation != "PyPy"',
+    (
+        'numpy; '
+        'sys_platform != "darwin" and '
+        'platform_python_implementation != "PyPy"'
+    ),
 
-    # Required by our optional "test_sphinx" functional test.
-    'sphinx',
+    # Required by optional Pandera-specific integration tests.
+    'pandera',
+
+    # Required by optional Sphinx-specific integration tests.
+    #
+    # Note that Sphinx currently provokes unrelated test failures under Python
+    # 3.7, due to dynamic importation functionality in the @beartype codebase
+    # invoking the third-party "pkg_resources" package, which then erupts with
+    # an obscure deprecation warning caused by Sphinx. Since *ALL* of this only
+    # applies to Python 3.7, we crudely circumvent this nonsense by simply
+    # avoiding installing Sphinx under Python 3.7. The exception resembles:
+    #     FAILED
+    #     ../../../beartype_test/a00_unit/a20_util/test_utilobject.py::test_is_object_hashable
+    #     - beartype.roar.BeartypeModuleUnimportableWarning: Ignoring module
+    #     "pkg_resources.__init__" importation exception DeprecationWarning:
+    #     Deprecated call to `pkg_resources.declare_namespace('sphinxcontrib')`.
+    'sphinx; python_version >= "3.8.0"',
 
     # Required to exercise beartype validators and thus functionality requiring
     # beartype validators (e.g., "numpy.typing.NDArray" type hints) under
@@ -473,8 +510,42 @@ See Also
     Further details.
 '''
 
-# ....................{ METADATA ~ libs : theme            }....................
-SPHINX_THEME_NAME = 'furo'
+# ....................{ METADATA ~ libs : doc : sphinx     }....................
+_SPHINX_VERSION_MINIMUM = '4.2.0'
+'''
+Machine-readable minimum (inclusive) version as a ``.``-delimited string of
+:mod:`sphinx` required to build package documentation.
+
+Specifically, this project requires:
+
+* :mod:sphinx` >= 4.2.0, which resolved a `severe compatibility issue`_ with
+  Python >= 3.10.
+
+.. _severe compatibility issue:
+   https://github.com/sphinx-doc/sphinx/issues/9816
+'''
+
+
+#FIXME: Once "pydata-sphinx-theme" 0.13.0 is released:
+#* Relax this restriction (e.g., by simply commenting this global out both here
+#  and below).
+#* Bump "_SPHINX_THEME_VERSION_MAXIMUM >= '0.13.0'" below.
+_SPHINX_VERSION_MAXIMUM_EXCLUSIVE = '6.0.0'
+'''
+Machine-readable maximum (exclusive) version as a ``.``-delimited string of
+:mod:`sphinx` required to build package documentation.
+
+Specifically, this project requires:
+
+* :mod:sphinx` < 6.0.0, as more recent versions `currently conflict with our
+  Sphinx theme <theme conflict_>`__.
+
+.. _theme conflict:
+   https://github.com/sphinx-doc/sphinx/issues/9816
+'''
+
+# ....................{ METADATA ~ libs : doc : theme      }....................
+SPHINX_THEME_NAME = 'pydata-sphinx-theme'
 '''
 Name of the third-party Sphinx extension providing the custom HTML theme
 preferred by this documentation.
@@ -486,41 +557,100 @@ selected the theme with:
 #. The most frequent git commit history.
 #. The open issues and pull requests (PRs).
 #. The most GitHub stars as a crude proxy for aggregate rating.
+#. **IS NOT STRONGLY OPINIONATED** (i.e., is configurable with standard Sphinx
+   settings and directives).
 
-Furo handily bested all other themes across all three criteria. Furo is very
-well-maintained, frequently closes out open issues and merges open PRs, and
-sports the highest quantity of GitHub stars by an overwhelming margin.
-
-See Also
+Furo
 ----------
-https://github.com/pradyunsg/furo
-    Upstream GitHub-hosted repository.
+Furo_ handily bested all other themes across the first three criteria. Furo is
+very well-maintained, frequently closes out open issues and merges open PRs, and
+sports the highest quantity of GitHub stars by an overwhelming margin. Sadly,
+Furo handily loses against literally unmaintained themes across the final
+criteria. Furo is absurdly strongly opinionated to an authoritarian degree we
+rarely find in open-source software. Why? Because it's principal maintainer is.
+Like maintainer, like software. Furo routinely ignores standard Sphinx settings
+and directives due to subjective opinions held by its maintainer, including:
+
+* Most user-defined ``:toctree:`` settings used to configure both global and
+  local tables of contents (TOCs) and thus the leftmost navigation sidebar,
+  effectively preventing users from using that sidebar to navigate to anything.
+  We are *not* kidding. ``:toctree:`` settings ignored by Furo include:
+
+  * ``:maxdepth:``. Internally, Furo forces the ``:titlesonly:`` setting by
+    passing ``titles_only=True`` to Sphinx's ``toctree()`` function at runtime.
+    Doing so effectively coerces ``:maxdepth: 1``, thus intentionally hiding
+    *all* document structure from the navigation sidebar -- where (usually)
+    *all* document structure is displayed. Users thus have no means of directly
+    jumping from the root landing page to child leaf documents, significantly
+    obstructing user experience (UX) and usability. See also this `feature
+    request <Furo discussion_>`__ to relax these constraints, to which the Furo
+    maintainer caustically replies:
+
+        No, there isn't any (supported) way to do this.
+
+        Separating the page content hierarchy and site structure was an explicit
+        design goal.
+
+We fundamentally disagree with those goals and have thus permanently switched
+away from Furo. Unjustified opinions are the little death of sanity.
+
+PyData
+======
+Furo and PyData are neck-and-neck with respect to git commit history; both are
+extremely well-maintained. Furo leaps ahead with respect to both issue and PR
+resolution, however; PyData has an extreme number of open issues and PRs, where
+Furo enjoys none. Moreover, Furo also enjoys dramatically more GitHub stars.
+
+Nonetheless, PyData is *not* strongly opinionated; Furo is. PyData does *not*
+silently ignore standard Sphinx settings and directives for largely indefensible
+reasons. Consequently, PyData wins by default. In fact, *any* other theme
+(including even unmaintained dead themes) wins by default; *no* other theme (to
+my limited knowledge) forcefully ignores standard Sphinx settings and directives
+to the extent that Furo does.
+
+PyData wins by *literally* doing nothing. Laziness prevails. All hail La-Z-Boy.
+
+.. _Furo:
+   https://github.com/pradyunsg/furo
+.. _Furo discussion:
+   https://github.com/pradyunsg/furo/discussions/146
 '''
 
 
-SPHINX_THEME_VERSION_MINIMUM = '2022.6.21'
+_SPHINX_THEME_VERSION_MAXIMUM = '0.7.2'
+# _SPHINX_THEME_VERSION_MAXIMUM = '0.12.0'
 '''
-Human-readable minimum version as a ``.``-delimited string of the **Furo Sphinx
-theme** (i.e., :mod:`furo`) optionally leveraged when building package
-documentation.
+Machine-readable maximum (inclusive) version as a ``.``-delimited string of the
+above Sphinx theme optionally leveraged when building package documentation.
+
+This theme is a rapidly moving target that frequently breaks backward
+compatibility. Although understandable, the fragility of this theme leaves us
+little alternatives but to pin to a **maximum** rather than **minimum** version
+of this theme. Specifically, this project requires:
+
+* :mod:pydata_sphinx_theme` <= 0.7.2, as our circumvention of both
+  pydata/pydata-sphinx-theme#90 and pydata/pydata-sphinx-theme#221 assumes a
+  reasonably older version of this theme. See also this currently `open issue`_.
+
+.. _open issue:
+   https://github.com/pydata/pydata-sphinx-theme/issues/1181
 '''
 
 # ....................{ METADATA ~ libs : doc              }....................
-_LIB_DOCTIME_MANDATORY_VERSION_MINIMUM_SPHINX = '4.1.0'
-'''
-Human-readable minimum version as a ``.``-delimited string of :mod:`sphinx`
-required to build package documentation.
-
-Specifically, this project requires:
-
-* :mod:sphinx` >= 4.1.0, which first supported the
-  ``autodoc_typehints = 'both'`` option.
-'''
-
-
 LIBS_DOCTIME_MANDATORY = (
-    f'sphinx >={_LIB_DOCTIME_MANDATORY_VERSION_MINIMUM_SPHINX}',
-    f'autoapi >=0.9.0',
+    # Sphinx itself.
+    (
+        f'sphinx '
+        f'>={_SPHINX_VERSION_MINIMUM}, '
+        f'<{_SPHINX_VERSION_MAXIMUM_EXCLUSIVE}'
+    ),
+
+    # Third-party Sphinx theme.
+    f'{SPHINX_THEME_NAME} <={_SPHINX_THEME_VERSION_MAXIMUM}',
+
+    # Third-party Sphinx extensions.
+    'autoapi >=0.9.0',
+    'sphinxext-opengraph >= 0.7.5',
 )
 '''
 **Mandatory developer documentation build-time package dependencies** (i.e.,
@@ -543,12 +673,15 @@ See Also
 '''
 
 
-LIBS_DOCTIME_MANDATORY_RTD = (
-    f'sphinx =={_LIB_DOCTIME_MANDATORY_VERSION_MINIMUM_SPHINX}',
-    (
-        f'{SPHINX_THEME_NAME} =={SPHINX_THEME_VERSION_MINIMUM}'
-    ),
-)
+#FIXME: For future use, we still preserve an RTD-specific list of requirements.
+#It's unclear whether we actually require this, however. Consider excising. The
+#prior approach of pinning exact Sphinx versions failed painfully by
+#accidentally constraining us to obsolete Sphinx versions known to be broken.
+LIBS_DOCTIME_MANDATORY_RTD = LIBS_DOCTIME_MANDATORY
+# LIBS_DOCTIME_MANDATORY_RTD = (
+#     f'sphinx =={_SPHINX_VERSION_MINIMUM}',
+#     f'{SPHINX_THEME_NAME} =={_SPHINX_THEME_VERSION_MAXIMUM}',
+# )
 '''
 **Mandatory Read The Docs (RTD) documentation build-time package dependencies**
 (i.e., dependencies required to automatically build documentation for this
