@@ -60,6 +60,7 @@ from beartype.roar._roarexc import (
     BeartypeDecorHintForwardRefException as BeartypeDecorHintForwardRefException,
     BeartypeDecorHintNonpepException as BeartypeDecorHintNonpepException,
     BeartypeDecorHintNonpepNumpyException as BeartypeDecorHintNonpepNumpyException,
+    BeartypeDecorHintNonpepPanderaException as BeartypeDecorHintNonpepPanderaException,
     BeartypeDecorHintPepException as BeartypeDecorHintPepException,
     BeartypeDecorHintPepSignException as BeartypeDecorHintPepSignException,
     BeartypeDecorHintPepUnsupportedException as BeartypeDecorHintPepUnsupportedException,
@@ -69,7 +70,9 @@ from beartype.roar._roarexc import (
     BeartypeDecorHintPep557Exception as BeartypeDecorHintPep557Exception,
     BeartypeDecorHintPep585Exception as BeartypeDecorHintPep585Exception,
     BeartypeDecorHintPep586Exception as BeartypeDecorHintPep586Exception,
+    BeartypeDecorHintPep591Exception as BeartypeDecorHintPep591Exception,
     BeartypeDecorHintPep593Exception as BeartypeDecorHintPep593Exception,
+    BeartypeDecorHintPep647Exception as BeartypeDecorHintPep647Exception,
     BeartypeDecorHintPep3119Exception as BeartypeDecorHintPep3119Exception,
     BeartypeDecorHintTypeException as BeartypeDecorHintTypeException,
     BeartypeDecorParamException as BeartypeDecorParamException,
@@ -95,7 +98,9 @@ from beartype.roar._roarexc import (
 from beartype.roar._roarwarn import (
     BeartypeWarning as BeartypeWarning,
     BeartypeClawWarning as BeartypeClawWarning,
-    BeartypeClawDecorationWarning as BeartypeClawDecorationWarning,
+    BeartypeClawDecorWarning as BeartypeClawDecorWarning,
+    BeartypeDecorHintWarning as BeartypeDecorHintWarning,
+    # BeartypeDecorHintForwardRefWarning as BeartypeDecorHintForwardRefWarning,
     BeartypeDecorHintPepWarning as BeartypeDecorHintPepWarning,
     BeartypeDecorHintPepDeprecationWarning as BeartypeDecorHintPepDeprecationWarning,
     BeartypeDecorHintPep585DeprecationWarning as BeartypeDecorHintPep585DeprecationWarning,
